==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/igr-snackbar.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Snackbar } from "./Snackbar";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcSnackbarComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * A snackbar component is used to provide feedback about an operation
 * by showing a brief message at the bottom of the screen.
*/
export class IgrSnackbar extends React.Component {
    createImplementation() {
        return new Snackbar();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._action = null;
        this._action_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcSnackbarComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => this.setState({}));
        this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-snackbar", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Determines whether the snackbar is opened.
    */
    get open() {
        return this.i.e;
    }
    set open(v) {
        this.i.e = ensureBool(v);
    }
    /**
     * Determines the duration in ms in which the snackbar will be visible.
    */
    get displayTime() {
        return this.i.f;
    }
    set displayTime(v) {
        this.i.f = +v;
    }
    /**
     * Determines whether the snackbar should close after the displayTime is over.
    */
    get keepOpen() {
        return this.i.d;
    }
    set keepOpen(v) {
        this.i.d = ensureBool(v);
    }
    /**
     * The snackbar action button.
    */
    get actionText() {
        return this.i.i;
    }
    set actionText(v) {
        this.i.i = v;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Snackbar");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Opens the snackbar.
    
    */
    show() {
        this.i.m();
    }
    /**
     * Closes the snackbar.
    
    */
    hide() {
        this.i.k();
    }
    /**
     * Toggles the open state of the component.
    
    */
    toggle() {
        this.i.n();
    }
    get action() {
        return this._action;
    }
    set action(ev) {
        if (this._action_wrapped !== null) {
            this.i.action = delegateRemove(this.i.action, this._action_wrapped);
            this._action_wrapped = null;
            this._action = null;
        }
        this._action = ev;
        this._action_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAction) {
                this.beforeAction(this, outerArgs);
            }
            if (this._action) {
                this._action(this, outerArgs);
            }
        };
        this.i.action = delegateCombine(this.i.action, this._action_wrapped);
        if (this.i.actionChanged) {
            this.i.actionChanged();
        }
        ;
    }
}

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/igr-snackbar.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { IgrBaseAlertLike } from "./igr-base-alert-like";
import { Snackbar } from "./Snackbar";
import { IgcSnackbarComponent, defineComponents } from "igniteui-webcomponents";
/**
 * A snackbar component is used to provide feedback about an operation
 * by showing a brief message at the bottom of the screen.
*/
export class IgrSnackbar extends IgrBaseAlertLike {
    createImplementation() {
        return new Snackbar();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._action = null;
        this._action_wrapped = null;
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcSnackbarComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-snackbar", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The snackbar action button.
    */
    get actionText() {
        return this.i.n;
    }
    set actionText(v) {
        this.i.n = v;
    }
    get action() {
        return this._action;
    }
    set action(ev) {
        if (this._action_wrapped !== null) {
            this.i.action = delegateRemove(this.i.action, this._action_wrapped);
            this._action_wrapped = null;
            this._action = null;
        }
        this._action = ev;
        this._action_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAction) {
                this.beforeAction(this, outerArgs);
            }
            if (this._action) {
                this._action(this, outerArgs);
            }
        };
        this.i.action = delegateCombine(this.i.action, this._action_wrapped);
        if (this.i.actionChanged) {
            this.i.actionChanged();
        }
        ;
    }
}
